@@ -426,7 +426,7 @@ module Parser
     def regexp_compose(begin_t, parts, end_t, options)
       begin
         static_regexp(parts, options)
-      rescue RegexpError => e
+      rescue RegexpError, Encoding::UndefinedConversionError => e
         diagnostic :error, :invalid_regexp, { :message => e.message },
                    loc(begin_t).join(loc(end_t))
       end
@@ -524,10 +524,10 @@ module Parser
 
       label = value(key_t)
       value =
-        if label =~ /\A[[:lower:]]/
-          n(:ident, [ label.to_sym ], Source::Map::Variable.new(value_l))
-        else
+        if label =~ /\A[[:upper:]]/
           n(:const, [ nil, label.to_sym ], Source::Map::Constant.new(nil, value_l, value_l))
+        else
+          n(:ident, [ label.to_sym ], Source::Map::Variable.new(value_l))
         end
       pair_keyword(key_t, accessible(value))
     end
